@@ -1,4 +1,4 @@
-## Copyright (C) 2015 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2015-2020 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -51,15 +51,9 @@
 ## times with different specified server machines before starting to
 ## retrieve the results.
 ##
-## The specified function handle can refer to a function present at the
-## executing machine or be an anonymous function. In the latter case,
-## the function specification sent to the server includes the anonymous
-## functions context (generation of the sent function specification is
-## implemented in the Octave core). Sending a handle to a subfunction,
-## however, will currently not work. Sending a handle to a private
-## function will only work if its file path is the same at the server.
-## Sending an anonymous function using "varargin" in the argument list
-## will currently not work.
+## The specified function handle can refer to a function present at
+## the executing machine or be an anonymous function. See
+## @code{parallel_doc ("limitations")} for possible limitations.
 ##
 ## @seealso{pconnect, pserver, sclose, install_vars, netcellfun}
 ## @end deftypefn
@@ -142,7 +136,7 @@ function ret = rfeval (varargin)
   unwind_protect_cleanup
 
     if (! ready)
-      sclose (conns); # might already be closed from within reval or psend
+      sclose (conn); # might already be closed from within reval or psend
     endif
 
   end_unwind_protect
