@@ -4,7 +4,7 @@ Copyright (C) 2016-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
+the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -50,7 +50,7 @@ _p_error (const char *fmt, ...)
 
   std::ostringstream output_buf;
 
-  octave_vformat (output_buf, fmt, args);
+  OCTAVE__VFORMAT (output_buf, fmt, args);
 
   std::string msg = output_buf.str ();
 
