@@ -21,7 +21,6 @@ this program; if not, see <http://www.gnu.org/licenses/>.
 
 #include <octave/oct.h>
 #include <octave/load-save.h>
-#include <octave/oct-stream.h>
 
 #include "minimal-load-save.h"
 
@@ -30,7 +29,6 @@ DEFUN_DLD (fload, args, ,
 @deftypefn {Loadable Function} {@var{var} =} fload (@var{fid})\n\
 Loads a single variable of any type from a binary stream, where it was previously\n\
 saved with fsave.\n\
-Not suitable for data transfer between machines of different type.\n\
 @end deftypefn")
 {
   octave_value retval;
@@ -38,16 +36,21 @@ Not suitable for data transfer between machines of different type.\n\
 
   if (nargin == 1)
     {
-      int fid = octave_stream_list::get_file_number (args (0));
+      int fid = OCTAVE__INTERPRETER__STREAM_LIST__GET_FILE_NUMBER (args (0));
 
-      octave_stream octs = octave_stream_list::lookup (fid, "fload");
+      OCTAVE__STREAM octs = OCTAVE__INTERPRETER__STREAM_LIST__LOOKUP
+        (fid, "fload");
       std::istream *is = octs.input_stream ();
 
       if (is)
         {
           bool swap;
-          oct_mach_info::float_format flt_fmt;
+          OCTAVE__MACH_INFO::float_format flt_fmt;
 
+          // This wouldn't be necessary within the local machine, but
+          // fload may be used outside parcellfun and the current
+          // version of parcellfun will become deprecated anyway since
+          // it forkes Octave.
           if (minimal_read_header (*is, swap, flt_fmt))
             {
               error ("fload: could not read binary header");
