@@ -71,7 +71,7 @@ one position more than the number of servers given in @var{hosts}\n\
 (except if @var{hosts} was given in the above mentioned deprecated\n\
 way). You can display the variable of network connections to see what\n\
 is in it. The variable of network connections, or subsets of it, is\n\
-passed to the other functions for parallel cluster excecution\n\
+passed to the other functions for parallel cluster execution\n\
 (@code{reval}, @code{psend}, @code{precv}, @code{sclose},\n\
 @code{select_sockets} among others -- see documentation of these\n\
 functions).\n\
